package com.qianhe.service;

import java.util.List;
import com.qianhe.domain.BzscSczhzxscZb;

/**
 * 标准手册-生产指挥中心管理手册-主Service接口
 * 
 * @author qianhe
 * @date 2024-09-19
 */
public interface IBzscSczhzxscZbService 
{
    /**
     * 查询标准手册-生产指挥中心管理手册-主
     * 
     * @param ID 标准手册-生产指挥中心管理手册-主主键
     * @return 标准手册-生产指挥中心管理手册-主
     */
    public BzscSczhzxscZb selectBzscSczhzxscZbByID(Long ID);

    /**
     * 查询标准手册-生产指挥中心管理手册-主列表
     * 
     * @param bzscSczhzxscZb 标准手册-生产指挥中心管理手册-主
     * @return 标准手册-生产指挥中心管理手册-主集合
     */
    public List<BzscSczhzxscZb> selectBzscSczhzxscZbList(BzscSczhzxscZb bzscSczhzxscZb);

    /**
     * 新增标准手册-生产指挥中心管理手册-主
     * 
     * @param bzscSczhzxscZb 标准手册-生产指挥中心管理手册-主
     * @return 结果
     */
    public int insertBzscSczhzxscZb(BzscSczhzxscZb bzscSczhzxscZb);

    /**
     * 修改标准手册-生产指挥中心管理手册-主
     * 
     * @param bzscSczhzxscZb 标准手册-生产指挥中心管理手册-主
     * @return 结果
     */
    public int updateBzscSczhzxscZb(BzscSczhzxscZb bzscSczhzxscZb);

    /**
     * 批量删除标准手册-生产指挥中心管理手册-主
     * 
     * @param IDs 需要删除的标准手册-生产指挥中心管理手册-主主键集合
     * @return 结果
     */
    public int deleteBzscSczhzxscZbByIDs(Long[] IDs);

    /**
     * 删除标准手册-生产指挥中心管理手册-主信息
     * 
     * @param ID 标准手册-生产指挥中心管理手册-主主键
     * @return 结果
     */
    public int deleteBzscSczhzxscZbByID(Long ID);
}
